@@ -42,6 +42,13 @@ try:
     )
 except ImportError:
     pass
+try:
+    # topk dependency is optional
+    from superlinked.framework.dsl.storage.topk_vector_database import (
+        TopKVectorDatabase,
+    )
+except ImportError:
+    pass
 from superlinked.evaluation.pandas_converter import PandasConverter
 from superlinked.evaluation.vector_sampler import VectorSampler
 from superlinked.framework.blob.blob_handler_factory import BlobHandlerConfig
@@ -50,15 +57,18 @@ from superlinked.framework.common.dag.period_time import PeriodTime
 from superlinked.framework.common.nlq.open_ai import OpenAIClientConfig
 from superlinked.framework.common.parser.dataframe_parser import DataFrameParser
 from superlinked.framework.common.parser.json_parser import JsonParser
+from superlinked.framework.common.precision import Precision
 from superlinked.framework.common.schema.event_schema import EventSchema, event_schema
 from superlinked.framework.common.schema.event_schema_object import (
     CreatedAtField,
     SchemaReference,
 )
-from superlinked.framework.common.schema.id_schema_object import IdField
+from superlinked.framework.common.schema.id_field import IdField
 from superlinked.framework.common.schema.schema import Schema, schema
 from superlinked.framework.common.schema.schema_object import (
     Blob,
+    Boolean,
+    DescribedBlob,
     Float,
     FloatList,
     Integer,
@@ -74,6 +84,18 @@ from superlinked.framework.common.space.config.embedding.number_embedding_config
     LogarithmicScale,
     Mode,
 )
+from superlinked.framework.common.space.config.embedding.text_similarity_embedding_config import (
+    TextModelHandler,
+)
+from superlinked.framework.common.space.embedding.model_based.engine.embedding_engine_config import (
+    EmbeddingEngineConfig,
+)
+from superlinked.framework.common.space.embedding.model_based.engine.modal_engine_config import (
+    ModalEngineConfig,
+)
+from superlinked.framework.common.storage.search_index.search_algorithm import (
+    SearchAlgorithm,
+)
 from superlinked.framework.common.util.interactive_util import get_altair_renderer
 from superlinked.framework.dsl.app.interactive.interactive_app import InteractiveApp
 from superlinked.framework.dsl.executor.in_memory.in_memory_executor import (
@@ -90,6 +112,7 @@ from superlinked.framework.dsl.index.effect import Effect
 from superlinked.framework.dsl.index.index import Index
 from superlinked.framework.dsl.query.param import Param
 from superlinked.framework.dsl.query.query import Query
+from superlinked.framework.dsl.query.query_user_config import QueryUserConfig
 from superlinked.framework.dsl.query.result import QueryResult
 from superlinked.framework.dsl.registry.superlinked_registry import SuperlinkedRegistry
 from superlinked.framework.dsl.source.data_loader_source import (
@@ -107,6 +130,7 @@ from superlinked.framework.dsl.space.custom_space import CustomSpace
 from superlinked.framework.dsl.space.image_space import ImageSpace
 from superlinked.framework.dsl.space.number_space import NumberSpace
 from superlinked.framework.dsl.space.recency_space import RecencySpace
+from superlinked.framework.dsl.space.space import Space
 from superlinked.framework.dsl.space.text_similarity_space import (
     TextSimilaritySpace,
     chunk,
@@ -144,17 +168,26 @@ __all__ = [
     "FloatList",
     "IdField",
     "Integer",
+    "Boolean",
     "SchemaReference",
     "String",
     "StringList",
     "Timestamp",
+    "DescribedBlob",
     # Number Space Config
     "Mode",
+    # Text/Image Space Config
+    "EmbeddingEngineConfig",
+    "ModalEngineConfig",
+    # Text Similarity Space Config
+    "TextModelHandler",
     # DB
+    "SearchAlgorithm",
     "InMemoryVectorDatabase",
     "MongoDBVectorDatabase",
     "QdrantVectorDatabase",
     "RedisVectorDatabase",
+    "TopKVectorDatabase",
     # Data loader
     "DataFormat",
     "DataLoaderConfig",
@@ -178,7 +211,9 @@ __all__ = [
     "Query",
     "RestQuery",
     "QueryResult",
+    "QueryUserConfig",
     # DSL Space
+    "Space",
     "CategoricalSimilaritySpace",
     "CustomSpace",
     "ImageSpace",
@@ -197,10 +232,16 @@ __all__ = [
     # misc
     "SuperlinkedRegistry",
     "BlobHandlerConfig",
+    "Precision",
 ]
 
+
 from superlinked.framework.common.superlinked_logging import (
     SuperlinkedLoggerConfigurator,
 )
+from superlinked.framework.common.telemetry.telemetry_configurator import (
+    SuperlinkedTelemetryConfigurator,
+)
 
 SuperlinkedLoggerConfigurator.configure_default_logger()
+SuperlinkedTelemetryConfigurator.configure_default_metrics()
