@@ -46,7 +46,7 @@ from superlinked.framework.common.space.interface.has_transformation_config impo
 )
 
 
-@dataclass
+@dataclass(frozen=True)
 class EventAggregationNodeInitParams(Generic[AggregationInputT, EmbeddingInputT]):
     input_to_aggregate: EmbeddingNode[AggregationInputT, EmbeddingInputT]
     event_schema: EventSchemaObject
@@ -70,7 +70,7 @@ class EventAggregationNode(
             Vector,
             [init_params.input_to_aggregate] + [filter.item for filter in init_params.filter_inputs],
             dag_effects=set(init_params.dag_effects),
-            persistence_params=PersistenceParams(persist_evaluation_result=True, persist_parent_evaluation_result=True),
+            persistence_params=PersistenceParams(persist_node_result=True, persist_parent_node_result=True),
             non_nullable_parents=frozenset([filter.item for filter in init_params.filter_inputs]),
         )
         self.schemas = {
@@ -100,9 +100,8 @@ class EventAggregationNode(
     def _get_node_id_parameters(self) -> dict[str, Any]:
         filters = [{"node_id": filter_.item.node_id, "weight": filter_.weight} for filter_ in self.filters]
         return {
-            "dag_effects": self.dag_effects,
-            "schemas": self.schemas,
-            "event_schema": self.event_schema,
+            "schemas": {schema._schema_name for schema in self.schemas},
+            "event_schema": self.event_schema._schema_name,
             "affected_schema": self.affected_schema,
             "affecting_schema": self.affecting_schema,
             "filters": filters,
