@@ -70,7 +70,7 @@ class Node(Generic[NodeDataT], ABC):  # pylint: disable=too-many-instance-attrib
 
     def _append_child(self, child: Node) -> None:
         self.children.append(child)
-        self._persistence_params.persist_evaluation_result |= child._persistence_params.persist_parent_evaluation_result
+        self._persistence_params.persist_node_result |= child._persistence_params.persist_parent_node_result
 
     @property
     def node_data_type(self) -> type[NodeDataT]:
@@ -91,8 +91,8 @@ class Node(Generic[NodeDataT], ABC):  # pylint: disable=too-many-instance-attrib
         return self.__class__.__name__
 
     @property
-    def persist_evaluation_result(self) -> bool:
-        return self._persistence_params.persist_evaluation_result
+    def persist_node_result(self) -> bool:
+        return self._persistence_params.persist_node_result
 
     @property
     def persistence_type(self) -> PersistenceType:
@@ -109,11 +109,15 @@ class Node(Generic[NodeDataT], ABC):  # pylint: disable=too-many-instance-attrib
         return f"{self.class_name}({members})"
 
     def _generate_node_id(self) -> str:
+        to_hash = self._calculate_node_id_hash_input()
+        return hashlib.sha3_256(to_hash.encode()).hexdigest()[:16]
+
+    def _calculate_node_id_hash_input(self) -> str:
         to_hash = " | ".join(
             [StringUtil.sort_and_serialize(self._get_node_id_parameters())]
             + [parent.node_id for parent in self.parents]
         )
-        return hashlib.sha3_256(to_hash.encode()).hexdigest()[:16]
+        return to_hash
 
     def project_parents_to_schema(self, schema: SchemaObject) -> Sequence[Node]:
         if schema in self.schemas:
